#[non_exhaustive]pub struct PaymentRequired {
pub x402_version: Version2,
pub error: Option<CompactString>,
pub resource: ResourceInfo,
pub accepts: Vec<PaymentRequirements>,
pub extensions: Extensions,
}Expand description
Body of an HTTP 402 Payment Required response.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.x402_version: Version2Protocol version (always 2).
error: Option<CompactString>Optional error message describing why the request was rejected.
resource: ResourceInfoResource metadata.
accepts: Vec<PaymentRequirements>Accepted payment terms.
extensions: ExtensionsOptional extension block.
Implementations
Sourceimpl PaymentRequired
impl PaymentRequired
Sourcepub fn new(resource: ResourceInfo) -> Self
pub fn new(resource: ResourceInfo) -> Self
Constructs a 402 body with the resource and an empty accepts list.
Sourcepub fn with_accepts(self, accepts: Vec<PaymentRequirements>) -> Self
pub fn with_accepts(self, accepts: Vec<PaymentRequirements>) -> Self
Replaces the accepted payment requirements list.
Sourcepub fn add_accept(self, accept: PaymentRequirements) -> Self
pub fn add_accept(self, accept: PaymentRequirements) -> Self
Appends a single payment requirement.
Sourcepub fn with_error(self, error: impl Into<CompactString>) -> Self
pub fn with_error(self, error: impl Into<CompactString>) -> Self
Attaches a human-readable error message.
Sourcepub fn with_extensions(self, extensions: Extensions) -> Self
pub fn with_extensions(self, extensions: Extensions) -> Self
Replaces the extensions block.